Module action

Module action 

Structs

Sleep
Sleep action represents a delay in the execution of the action sequence.

Enums

ActionError
ActionError defines the possible errors that can occur during action execution.

Traits

Action
Action trait defines the interface for actions that can be performed in the system.