Crate nseqe

Crate nseqe 

Modules

action
protocol

Structs

Node
Represents a node in the network, which can perform actions and maintain its context.
ReceiveEvent
Represents an event that occurs when data is received over a network socket.